<?php
/**
 * MyBB 1.4
 * Copyright  2008 MyBB Group, All Rights Reserved
 *
 * Website: http://www.mybboard.net
 * License: http://www.mybboard.net/about/license
 *
 * $Id: index.php 4442 2009-08-25 10:24:16Z Tomm $
 */

if(function_exists("unicode_decode"))
{
    // Unicode extension introduced in 6.0
    error_reporting(E_ALL ^ E_DEPRECATED ^ E_NOTICE ^ E_STRICT);
}
elseif(defined("E_DEPRECATED"))
{
    // E_DEPRECATED introduced in 5.3
    error_reporting(E_ALL ^ E_DEPRECATED ^ E_NOTICE);
}
else
{
    error_reporting(E_ALL & ~E_NOTICE);
}

@set_time_limit(0);

define('MYBB_ROOT', dirname(dirname(__FILE__))."/");
define("INSTALL_ROOT", dirname(__FILE__)."/");
define("TIME_NOW", time());
define("IN_MYBB", 1);
define("IN_INSTALL", 1);

require_once MYBB_ROOT.'inc/class_core.php';
$mybb = new MyBB;

require_once MYBB_ROOT.'inc/class_error.php';
$error_handler = new errorHandler();

// Include the files necessary for installation
require_once MYBB_ROOT.'inc/class_timers.php';
require_once MYBB_ROOT.'inc/functions.php';

$admin_dir = "admin";

// Perform a check if MyBB is already installed or not
$installed = false;
if(file_exists(MYBB_ROOT."/inc/config.php"))
{
	require MYBB_ROOT."/inc/config.php";
	if(is_array($config))
	{
		$installed = true;
		if(isset($config['admindir']))
		{
			$admin_dir = $config['admindir'];
		}
		else if(isset($config['admin_dir']))
		{
			$admin_dir = $config['admin_dir'];
		}
	}
}

require_once MYBB_ROOT.'inc/class_xml.php';
require_once MYBB_ROOT.'inc/functions_user.php';
require_once MYBB_ROOT.'inc/class_language.php';
$lang = new MyLanguage();
$lang->set_path(MYBB_ROOT.'install/resources');
$lang->load('language');

// Prevent any shut down functions from running
$done_shutdown = 1;

// Include the necessary contants for installation
$grouppermignore = array('gid', 'type', 'title', 'description', 'namestyle', 'usertitle', 'stars', 'starimage', 'image');
$groupzerogreater = array('pmquota', 'maxreputationsday', 'attachquota');
$displaygroupfields = array('title', 'description', 'namestyle', 'usertitle', 'stars', 'starimage', 'image');
$fpermfields = array('canview', 'candlattachments', 'canpostthreads', 'canpostreplys', 'canpostattachments', 'canratethreads', 'caneditposts', 'candeleteposts', 'candeletethreads', 'caneditattachments', 'canpostpolls', 'canvotepolls', 'cansearch');

// Include the installation resources
require_once INSTALL_ROOT.'resources/output.php';
$output = new installerOutput;

$dboptions = array();

if(function_exists('mysqli_connect'))
{
	$dboptions['mysqli'] = array(
		'class' => 'DB_MySQLi',
		'title' => 'MySQL Improved',
		'short_title' => 'MySQLi',
		'structure_file' => 'mysql_db_tables.php',
		'population_file' => 'mysql_db_inserts.php'
	);
}

if(function_exists('mysql_connect'))
{
	$dboptions['mysql'] = array(
		'class' => 'DB_MySQL',
		'title' => 'MySQL',
		'short_title' => 'MySQL',
		'structure_file' => 'mysql_db_tables.php',
		'population_file' => 'mysql_db_inserts.php'
	);
}

if(function_exists('sqlite_open'))
{
	$dboptions['sqlite2'] = array(
		'class' => 'DB_SQLite2',
		'title' => 'SQLite 2',
		'short_title' => 'SQLite',
		'structure_file' => 'sqlite_db_tables.php',
		'population_file' => 'mysql_db_inserts.php'
	);
}

if(function_exists('pg_connect'))
{
	$dboptions['pgsql'] = array(
		'class' => 'DB_PgSQL',
		'title' => 'PostgreSQL',
		'short_title' => 'PostgreSQL',
		'structure_file' => 'pgsql_db_tables.php',
		'population_file' => 'mysql_db_inserts.php'
	);
}

if(class_exists('PDO'))
{
	$supported_dbs = PDO::getAvailableDrivers();
	if(in_array('sqlite', $supported_dbs))
	{
		$dboptions['sqlite3'] = array(
			'class' => 'DB_SQLite3',
			'title' => 'SQLite 3',
			'short_title' => 'SQLite',
			'structure_file' => 'sqlite_db_tables.php',
			'population_file' => 'mysql_db_inserts.php'
		);
	}
}

if(file_exists('lock'))
{
	$output->print_error($lang->locked);
}
else if($installed == true && !$mybb->input['action'])
{
	$output->print_header($lang->already_installed, "errormsg", 0);
	echo $lang->sprintf($lang->mybb_already_installed, $mybb->version);
	$output->print_footer();
}
else
{
	$output->steps = array(
		'intro' => $lang->welcome,
		'license' => $lang->license_agreement,
		'requirements_check' => $lang->req_check,
		'database_info' => $lang->db_config,
		'create_tables' => $lang->table_creation,
		'populate_tables' => $lang->data_insertion,
		'templates' => $lang->theme_install,
		'configuration' => $lang->board_config,
		'adminuser' => $lang->admin_user,
		'final' => $lang->finish_setup,
	);
	
	if(!isset($mybb->input['action']))
	{
		$mybb->input['action'] = 'intro';
	}
	
	switch($mybb->input['action'])
	{
		case 'license':
			license_agreement();
			break;
		case 'requirements_check':
			requirements_check();
			break;
		case 'database_info':
			database_info();
			break;
		case 'create_tables':
			create_tables();
			break;
		case 'populate_tables':
			populate_tables();
			break;
		case 'templates':
			insert_templates();
			break;
		case 'configuration':
			configure();
			break;
		case 'adminuser';
			create_admin_user();
			break;
		case 'final':
			install_done();
			break;
		default:
			intro();
			break;
	}
}

function intro()
{
	global $output, $mybb, $lang;
	
	$output->print_header($lang->welcome, 'welcome');
	if(strpos(strtolower($_SERVER['PHP_SELF']), "upload/") !== false)
	{
		echo $lang->sprintf($lang->mybb_incorrect_folder);
	}
	echo $lang->sprintf($lang->welcome_step, $mybb->version);
	$output->print_footer('license');
}

function license_agreement()
{
	global $output, $lang, $mybb;
	
	ob_start();
	$output->print_header($lang->license_agreement, 'license');
	
	if($mybb->input['allow_anonymous_info'] == 1)
	{
		require_once MYBB_ROOT."inc/functions_serverstats.php";
		$build_server_stats = build_server_stats(1, '', $mybb->version_code, $mybb->config['database']['encoding']);
		
		if($build_server_stats['info_sent_success'] == false)
		{
			echo $build_server_stats['info_image'];
		}
	}
	ob_end_flush();

	$license = <<<EOF
<pre>
                    LICENCE PUBLIQUE G&Eacute;N&Eacute;RALE GNU
                      Version 3, du 29 Juin 2007

 Copyright (C) 2007 Free Software Foundation, Inc. &lt;http://fsf.org/&gt;
 Chacun est autoris&eacute; &agrave; copier et distribuer des copies conformes de ce document
 de licence, mais toute modification en est proscrite.

                            Pr&eacute;ambule

La Licence Publique G&eacute;n&eacute;rale GNU (GNU General Public License) est une licence libre,
en copyleft, destin&eacute;e aux &oelig;uvres logicielles et dautres types de travaux.

Les licences de la plupart des &oelig;uvres logicielles et autres travaux de pratique sont con&ccedil;ues
pour &ocirc;ter votre libert&eacute; de partager et modifier ces travaux. En contraste, la Licence Publique
G&eacute;n&eacute;rale GNU a pour but de garantir votre libert&eacute; de partager et changer toutes les versions
dun programme  afin dassurer quil restera libre pour tous les utilisateurs. Nous, la Free
Software Foundation, utilisons la Licence Publique G&eacute;n&eacute;rale GNU pour la plupart de nos logiciels ;
cela sapplique aussi &agrave; tout autre travail &eacute;dit&eacute; de cette fa&ccedil;on par ses auteurs. Vous pouvez,
vous aussi, lappliquer &agrave; vos propres programmes.

Quand nous parlons de logiciel libre (free), nous nous r&eacute;f&eacute;rons &agrave; la libert&eacute; (freedom),
pas au prix. Nos Licences Publiques G&eacute;n&eacute;rales sont con&ccedil;ues pour assurer que vous ayez la libert&eacute;
de distribuer des copies de logiciel libre (et le facturer si vous le souhaitez), que vous receviez
le code source ou pouviez lobtenir si vous le voulez, que vous pouviez modifier le logiciel ou en
utiliser toute partie dans de nouveaux logiciels libres, et que vous sachiez que vous avez le droit de faire tout ceci.

Pour prot&eacute;ger vos droits, nous avons besoin demp&ecirc;cher que dautres vous restreignent ces droits
ou vous demande de leur abandonner ces droits. En cons&eacute;quence, vous avez certaines responsabilit&eacute;s
si vous distribuez des copies dun tel programme ou si vous le modifiez : les responsabilit&eacute;s de
respecter la libert&eacute; des autres.

Par exemple, si vous distribuez des copies dun tel programme, que ce soit gratuit ou contre un paiement,
vous devez accorder aux Destinataires les m&ecirc;mes libert&eacute;s que vous avez re&ccedil;ues. Vous devez aussi vous assurer
queux aussi re&ccedil;oivent ou peuvent recevoir son code source. Et vous devez leur montrer les termes de cette
licence afin quils connaissent leurs droits.

Les d&eacute;veloppeurs qui utilisent la GPL GNU prot&egrave;gent vos droits en deux &eacute;tapes : (1) ils affirment
leur droits dauteur (copyright) sur le logiciel, et (2) vous accordent cette Licence qui vous donne
la permission l&eacute;gale de le copier, le distribuer et/ou le modifier.

Pour la protection des d&eacute;veloppeurs et auteurs, la GPL stipule clairement quil ny a pas de garantie
pour ce logiciel libre. Aux fins &agrave; la fois des utilisateurs et auteurs, la GPL requi&egrave;re que les versions
modifi&eacute;es soient marqu&eacute;es comme chang&eacute;es, afin que leurs probl&egrave;mes ne soient pas attribu&eacute;s de fa&ccedil;on
erron&eacute;e aux auteurs des versions pr&eacute;c&eacute;dentes.

Certains dispositifs sont con&ccedil;us pour emp&ecirc;cher lacc&egrave;s des utilisateurs &agrave; linstallation ou lex&eacute;cution
de versions modifi&eacute;es du logiciel &agrave; lint&eacute;rieur de ces dispositifs, alors que les fabricants le peuvent.
Ceci est fondamentalement incompatible avec le but de prot&eacute;ger la libert&eacute; des utilisateurs de modifier
le logiciel. Laspect syst&eacute;matique de tels abus se produit dans le secteur des produits destin&eacute;s aux
utilisateurs individuels, ce qui est pr&eacute;cid&eacute;ment ce qui est le plus inacceptable. Aussi, nous avons
con&ccedil;u cette version de la GPL pour prohiber cette pratique pour ces produits. Si de tels probl&egrave;mes
surviennent dans dautres domaines, nous nous tenons pr&ecirc;t &agrave; &eacute;tendre cette restriction &agrave; ces domaines
dans de futures versions de la GPL, autant quil sera n&eacute;cessaire pour prot&eacute;ger la libert&eacute; des utilisateurs.

Finalement, chaque programme est constamment menac&eacute; par les brevets logiciels. Les &Eacute;tats ne devraient pas
autoriser de tels brevets &agrave; restreindre le d&eacute;veloppement et lutilisation de logiciels libres sur des
ordinateurs dusage g&eacute;n&eacute;ral ; mais dans ceux qui le font, nous voulons sp&eacute;cialement &eacute;viter le danger
que les brevets appliqu&eacute;s &agrave; un programme libre puisse le rendre effectivement propri&eacute;taire. Pour
emp&ecirc;cher ceci, la GPL assure que les brevets ne peuvent &ecirc;tre utilis&eacute;s pour rendre le programme non-libre.

Les termes pr&eacute;cis et conditions concernant la copie, la distribution et la modification suivent.
	
                       TERMES ET CONDITIONS

  Article 0. D&eacute;finitions.

  &laquo;Cette Licence&raquo; se r&eacute;f&egrave;re &agrave; la version 3 de la GNU General Public License (le texte original en anglais).

  &laquo;Droit dAuteur&raquo; signifie aussi les droits du copyright ou voisins qui sappliquent &agrave; dautres types de travaux,
tels que ceux sur les masques de semi-conducteurs.

  &laquo;Le Programme&raquo; se r&eacute;f&egrave;re &agrave; tout travail qui peut &ecirc;tre sujet au Droit dAuteur (copyright) et dont les droits
dutilisation sont conc&eacute;d&eacute;s en vertu de cette Licence. Chacun des Licenci&eacute;s, &agrave; qui cette Licence est conc&eacute;d&eacute;e,
est d&eacute;sign&eacute; par &laquo;vous.&raquo; Les &laquo;Licenci&eacute;s&raquo; et les &laquo;Destinataires&raquo; peuvent &ecirc;tre des personnes physiques ou
morales (individus ou organisations).

  &laquo;Modifier&raquo; un travail signifie en obtenir une copie et adapter tout ou partie du travail dune fa&ccedil;on n&eacute;cessitant
une autorisation dun titulaire de Droit dAuteur, autre que celle permettant den produire une copie conforme.
Le travail r&eacute;sultant est appel&eacute; une &laquo;version modifi&eacute;e&raquo; du pr&eacute;c&eacute;dent travail, ou un travail &laquo;bas&eacute; sur&raquo; le pr&eacute;c&eacute;dent travail.

  Un &laquo;Travail Couvert&raquo; signifie soit le Programme non modifi&eacute; soit un travail bas&eacute; sur le Programme.

  &laquo;Propager&raquo; un travail signifie faire quoi que ce soit avec lui qui, sans permission, vous rendrait directement
ou indirectement responsable dun d&eacute;lit de contrefa&ccedil;on suivant les lois relatives au Droit dAuteur, &agrave; lexception
de son ex&eacute;cution sur un ordinateur ou de la modification dune copie priv&eacute;e. La propagation inclue la copie, la
distribution (avec ou sans modification), la mise &agrave; disposition envers le public, et aussi d'autres activit&eacute;s dans certains pays.

  &laquo;Acheminer&raquo; un travail signifie tout moyen de propagation de celui-ci qui permet &agrave; dautres parties de r&eacute;aliser
ou recevoir des copies. La simple interaction dun utilisateur &agrave; travers un r&eacute;seau informatique, sans transfert
effectif dune copie, ne constitue pas un acheminement.

  Une interface utilisateur interactive affiche des &laquo;Notices L&eacute;gales Appropri&eacute;es&raquo; quand elle comprend un dispositif
convenable, bien visible et &eacute;vident qui (1) affiche une notice appropri&eacute;e sur les droits dauteur et (2) informe
lutilisateur quil ny a pas de garantie pour le travail (sauf si des garanties ont &eacute;t&eacute; fournies hors du cadre de cette
Licence), que les licenci&eacute;s peuvent acheminer le travail sous cette Licence, et comment voir une copie de cette Licence.
Si linterface pr&eacute;sente une liste de commandes utilisateur ou doptions, tel quun menu, un &eacute;l&eacute;ment &eacute;vident dans la liste pr&eacute;sent&eacute;e remplit ce crit&egrave;re.

  Article 1. Code source.

  Le &laquo;code source&raquo; dun travail signifie la forme pr&eacute;f&eacute;r&eacute;e du travail permettant ou facilitant les modifications de celui-ci.
Le &laquo;code objet&raquo; dun travail signifie toute forme du travail qui nen est pas le code source.

  Une &laquo;Interface Standard&raquo; signifie une interface qui est soit celle dune norme officielle d&eacute;finie par un organisme de
normalisation reconnu ou, dans le cas des interfaces sp&eacute;cifi&eacute;es pour un langage de programmation particulier, une interface
largement utilis&eacute;e parmi les d&eacute;veloppeurs travaillant dans ce langage.

  Les &laquo;Biblioth&egrave;ques Syst&egrave;me&raquo; dun travail ex&eacute;cutable incluent tout ce qui, en dehors du travail dans son ensemble,
(a) est inclus dans la forme usuelle de paquetage dun Composant Majeur mais ne fait pas partie de ce Composant Majeur
et (b) sert seulement &agrave; permettre lutilisation du travail avec ce Composant Majeur ou &agrave; impl&eacute;menter une Interface
Standard pour laquelle une impl&eacute;mentation est disponible au public sous forme de code source ; un &laquo;Composant Majeur&raquo;
signifie, dans ce contexte, un composant majeur essentiel (noyau, syst&egrave;me de fen&ecirc;trage, etc.) du syst&egrave;me dexploitation
(le cas &eacute;ch&eacute;ant) dun syst&egrave;me sur lequel le travail ex&eacute;cutable fonctionne, ou bien un compilateur utilis&eacute; pour produire
le code objet du travail, ou un interpr&egrave;te de code objet utilis&eacute; pour ex&eacute;cuter celui-ci.

  Le &laquo;Source Correspondant&raquo; dun travail sous forme de code objet signifie lensemble des codes sources n&eacute;cessaires
pour g&eacute;n&eacute;rer, installer et (dans le cas dun travail ex&eacute;cutable) ex&eacute;cuter le code objet et modifier le travail, y compris
les scripts pour contr&ocirc;ler ces activit&eacute;s. Cependant, cela ninclue pas les Biblioth&egrave;ques Syst&egrave;me du travail, ni les outils
dusage g&eacute;n&eacute;ral ou les programmes libres g&eacute;n&eacute;ralement disponibles qui peuvent &ecirc;tre utilis&eacute;s sans modification pour achever
ces activit&eacute;s mais ne sont pas partie de ce travail. Par exemple le Source Correspondant inclut les fichiers de d&eacute;finition
dinterfaces associ&eacute;s aux fichiers sources du travail, et le code source des biblioth&egrave;ques partag&eacute;es et des sous-routines
li&eacute;es dynamiquement, pour lesquelles le travail est sp&eacute;cifiquement con&ccedil;u pour les requ&eacute;rir via, par exemple,
des communications de donn&eacute;es ou contr&ocirc;les de flux internes entre ces sous-programmes et dautres parties du travail.

  Le Source Correspondant na pas besoin dinclure tout ce que les utilisateurs peuvent reg&eacute;n&eacute;rer automatiquement &agrave; partir
dautres parties du Source Correspondant.

  Le Source Correspondant pour un travail sous forme de code source est ce m&ecirc;me travail.
  
  Article 2. Permissions de base.

  Tous les droits accord&eacute;s suivant cette Licence le sont jusquau terme des Droits dAuteur (copyright) sur le Programme, et sont irr&eacute;vocables pourvu que les conditions &eacute;tablies soient remplies. Cette Licence affirme explicitement votre permission illimit&eacute;e dex&eacute;cuter le Programme non modifi&eacute;. La sortie produite par lex&eacute;cution dun Travail Couvert nest couverte par cette Licence que si cette sortie, &eacute;tant donn&eacute; leur contenu, constitue un Travail Couvert. Cette Licence reconnait vos propres droits dusage raisonnable (fair use en l&eacute;gislation des &Eacute;tats-Unis dAm&eacute;rique) ou autres &eacute;quivalents, tels quils sont pourvus par la loi applicable sur le Droit dAuteur (copyright).

  Vous pouvez cr&eacute;er, ex&eacute;cuter et propager sans condition des Travaux Couverts que vous nacheminez pas, aussi longtemps que votre licence demeure en vigueur. Vous pouvez acheminer des Travaux Couverts &agrave; dautres personnes dans le seul but de leur faire r&eacute;aliser des modifications &agrave; votre usage exclusif, ou pour quils vous fournissent des facilit&eacute;s vous permettant dex&eacute;cuter ces travaux, pourvu que vous vous conformiez aux termes de cette Licence lors de lacheminement de tout mat&eacute;riel dont vous ne contr&ocirc;lez pas le Droit dAuteur (copyright). Ceux qui, d&egrave;s lors, r&eacute;alisent ou ex&eacute;cutent pour vous les Travaux Couverts ne doivent alors le faire quexclusivement pour votre propre compte, sous votre direction et votre contr&ocirc;le, suivant des termes qui leur interdisent de r&eacute;aliser, en dehors de leurs relations avec vous, toute copie de votre mat&eacute;riel soumis au Droit dAuteur.

  Lacheminement dans toutes les autres circonstances nest permis que selon les conditions &eacute;tablies ci-dessous. La concession de sous-licences nest pas autoris&eacute; ; larticle 10 rend cet usage non n&eacute;cessaire.
Article 3. Protection des droits l&eacute;gaux des utilisateurs envers les lois anti-contournement.

  Aucun Travail Couvert ne doit &ecirc;tre vu comme faisant partie dune mesure technologique effective selon toute loi applicable remplissant les obligations pr&eacute;vues &agrave; larticle 11 du trait&eacute; international sur le droit dauteur adopt&eacute; &agrave; lOMPI le 20 d&eacute;cembre 1996, ou toutes lois similaires qui prohibent ou restreignent le contournement de telles mesures.

  Si vous acheminez un Travail Couvert, vous renoncez &agrave; tout pouvoir l&eacute;gal dinterdire le contournement des mesures technologiques dans tous les cas o&ugrave; un tel contournement serait effectu&eacute; en exer&ccedil;ant les droits pr&eacute;vus dans cette Licence pour ce Travail Couvert, et vous d&eacute;clarez rejeter toute intention de limiter lop&eacute;ration ou la modification du Travail, en tant que moyens de renforcer, &agrave; lencontre des utilisateurs de ce Travail, vos droits l&eacute;gaux ou ceux de tierces parties dinterdire le contournement des mesures technologiques.

  
  Article 4. Acheminement des copies conformes.

  Vous pouvez acheminer des copies conformes du code source du Programme tel que vous lavez re&ccedil;u, sur nimporte quel support, pourvu que vous publiiez scrupuleusement et de fa&ccedil;on appropri&eacute;e sur chaque copie une notice de Droit dAuteur appropri&eacute;e ; gardez intactes toutes les notices &eacute;tablissant que cette Licence et tous les termes additionnels non permissifs ajout&eacute;s en accord avec larticle 7 sappliquent &agrave; ce code ; et donnez &agrave; chacun des Destinataires une copie de cette Licence en m&ecirc;me temps que le Programme.

  Vous pouvez facturer un prix quelconque, y compris gratuit, pour chacune des copies que vous acheminez, et vous pouvez offrir une protection additionnelle de support ou de garantie en &eacute;change dun paiement.
Article 5. Acheminement des versions sources modifi&eacute;es.

  Vous pouvez acheminer un travail bas&eacute; sur le Programme, ou bien les modifications pour le produire &agrave; partir du Programme, sous la forme de code source suivant les termes de larticle 4, pourvu que vous satisfassiez aussi &agrave; chacune des conditions requises suivantes :

    * a) Le travail doit comporter des notices &eacute;videntes &eacute;tablissant que vous lavez modifi&eacute; et donnant la date correspondante.
    * b) Le travail doit comporter des notices &eacute;videntes &eacute;tablissant quil est &eacute;dit&eacute; selon cette Licence et les conditions ajout&eacute;es dapr&egrave;s larticle 7. Cette obligation vient modifier lobligation de larticle 4 de &laquo;garder intactes toutes les notices.&raquo;
    * c) Vous devez licencier le travail entier, comme un tout, suivant cette Licence &agrave; quiconque entre en possession dune copie. Cette Licence sappliquera en cons&eacute;quence, avec les termes additionnels applicables pr&eacute;vus par larticle 7, &agrave; la totalit&eacute; du travail et chacune de ses parties, ind&eacute;pendamment de la fa&ccedil;on dont ils sont empaquet&eacute;s. Cette licence ne donne aucune permission de licencier le travail dune autre fa&ccedil;on, mais elle ninvalide pas une telle permission si vous lavez re&ccedil;ue s&eacute;par&eacute;ment.
    * d) Si le travail a des interfaces utilisateurs interactives, chacune doit afficher les Notices L&eacute;gales Appropri&eacute;es ; cependant si le Programme a des interfaces qui naffichent pas les Notices L&eacute;gales Appropri&eacute;es, votre travail na pas &agrave; les modifier pour quelles les affichent.

  Une compilation dun Travail Couvert avec dautres travaux s&eacute;par&eacute;s et ind&eacute;pendants, qui ne sont pas par leur nature des extensions du Travail Couvert, et qui ne sont pas combin&eacute;s avec lui de fa&ccedil;on &agrave; former un programme plus large, dans ou sur un volume de stockage ou un support de distribution, est appel&eacute; un &laquo;aggr&eacute;gat&raquo; si la compilation et son Droit dAuteur r&eacute;sultant ne sont pas utilis&eacute;s pour limiter lacc&egrave;s ou les droits l&eacute;gaux des utilisateurs de la compilation en de&ccedil;a de ce que permettent les travaux individuels. Linclusion dun Travail Couvert dans un aggr&eacute;gat ne cause pas lapplication de cette Licence aux autres parties de laggr&eacute;gat.
Article 6. Acheminement des formes non sources.

  Vous pouvez acheminer sous forme de code objet un Travail Couvert suivant les termes des articles 4 et 5, pourvu que vous acheminiez &eacute;galement suivant les termes de cette Licence le Source Correspondant lisible par une machine, dune des fa&ccedil;ons suivantes :

    * a) Acheminer le code objet sur, ou inclus dans, un produit physique (y compris un support de distribution physique), accompagn&eacute; par le Source Correspondant fix&eacute; sur un support physique durable habituellement utilis&eacute; pour les &eacute;changes de logiciels.
    * b) Acheminer le code objet sur, ou inclus dans, un produit physique (y compris un support de distribution physique), accompagn&eacute; dune offre &eacute;crite, valide pour au moins trois ann&eacute;es et valide pour aussi longtemps que vous fournissez des pi&egrave;ces de rechange ou un support client pour ce mod&egrave;le de produit, afin de donner &agrave; quiconque poss&egrave;de le code objet soit (1) une copie du Source Correspondant &agrave; tout logiciel dans ce produit qui est couvert par cette Licence, sur un support physique durable habituellement utilis&eacute; pour les &eacute;changes de logiciels, pour un prix non sup&eacute;rieur au co&ucirc;t raisonnable de la r&eacute;alisation physique de lacheminement de la source, ou soit (2) un acc&egrave;s permettant de copier le Source Correspondant depuis un serveur r&eacute;seau sans frais.
    * c) Acheminer des copies individuelles du code objet avec une copie de loffre &eacute;crite de fournir le Source Correspondant. Cette alternative est permise seulement occasionellement et non-commercialement, et seulement si vous avez re&ccedil;u le code objet avec une telle offre, en accord avec larticle 6 alin&eacute;a b.
    * d) Acheminer le code objet en offrant un acc&egrave;s depuis un emplacement d&eacute;sign&eacute; (gratuit ou contre facturation) et offrir un acc&egrave;s &eacute;quivalent au Source Correspondant de la m&ecirc;me fa&ccedil;on via le m&ecirc;me emplacement et sans facturation suppl&eacute;mentaire. Vous navez pas besoin dobliger les Destinataires &agrave; copier le Source Correspondant en m&ecirc;me temps que le code objet. Si lemplacement pour copier le code objet est un serveur r&eacute;seau, le Source Correspondant peut &ecirc;tre sur un serveur diff&eacute;rent (op&eacute;r&eacute; par vous ou par un tiers) qui supporte des facilit&eacute;s &eacute;quivalentes de copie, pourvu que vous mainteniez des directions claires &agrave; proximit&eacute; du code objet indiquant o&ugrave; trouver le Source Correspondant. Ind&eacute;pendamment de quel serveur h&eacute;berge le Source Correspondant, vous restez oblig&eacute; de vous assurer quil reste disponible aussi longtemps que n&eacute;cessaire pour satisfaire &agrave; ces obligations.
    * e) Acheminer le code objet en utilisant une transmission d&eacute;gal-&agrave;-&eacute;gal, pourvu que vous informiez les autres participants sur o&ugrave; le code objet et le Source Correspondant du travail sont offerts sans frais au public g&eacute;n&eacute;ral suivant larticle 6 alin&eacute;a d.

  Une portion s&eacute;parable du code objet, dont le code source est exclu du Source Correspondant en tant que Biblioth&egrave;que Syst&egrave;me, na pas besoin d&ecirc;tre inclu dans lacheminement du travail sous forme de code objet.

  Un &laquo;Produit Utilisateur&raquo; est soit (1) un &laquo;Produit de Consommation,&raquo; ce qui signifie toute propri&eacute;t&eacute; personnelle tangible normalement utilis&eacute;e &agrave; des fins personnelles, familiales ou relatives au foyer, soit (2) toute chose con&ccedil;ue ou vendue pour lincorporation dans un lieu dhabitation. Pour d&eacute;terminer si un produit constitue un Produit de Consommation, les cas ambigus sont r&eacute;solus en fonction de la couverture. Pour un produit particulier re&ccedil;u par un utilisateur particulier, lexpression &laquo;normalement utilis&eacute;e&raquo; ci-avant se r&eacute;f&egrave;re &agrave; une utilisation typique ou lusage commun de produits de m&ecirc;me cat&eacute;gorie, ind&eacute;pendamment du statut de cet utilisateur particulier ou de la fa&ccedil;on sp&eacute;cifique dont cet utilisateur particulier utilise effectivement ou sattend lui-m&ecirc;me ou est attendu &agrave; utiliser ce produit. Un produit est un Produit de Consommation ind&eacute;pendamment du fait que ce produit a ou na pas dutilisations substantielles commerciales, industrielles ou hors Consommation, &agrave; moins que de telles utilisations repr&eacute;sentent le seul mode significatif dutilisation du produit.

  Les &laquo;Informations dInstallation&raquo; dun Produit Utilisateur signifient toutes les m&eacute;thodes, proc&eacute;dures, cl&eacute;s dautorisation ou autres informations requises pour installer et ex&eacute;cuter des versions modifi&eacute;es dun Travail Couvert dans ce Produit Utilisateur &agrave; partir dune version modifi&eacute;e de son Source Correspondant. Les informations qui suffisent &agrave; assurer la continuit&eacute; de fonctionnement du code objet modifi&eacute; ne doivent en aucun cas &ecirc;tre emp&ecirc;ch&eacute;es ou interf&eacute;r&eacute;es du seul fait quune modification a &eacute;t&eacute; effectu&eacute;e.

  Si vous acheminez le code objet dun Travail Couvert dans, ou avec, ou sp&eacute;cifiquement pour lutilisation dans, un Produit Utilisateur et lacheminement se produit en tant qu&eacute;l&eacute;ment dune transaction dans laquelle le droit de possession et dutilisation du Produit Utilisateur est transf&eacute;r&eacute; au Destinataire d&eacute;finitivement ou pour un terme fix&eacute; (ind&eacute;pendamment de la fa&ccedil;on dont la transaction est caract&eacute;ris&eacute;e), le Source Correspondant achemin&eacute; selon cet article-ci doit &ecirc;tre accompagn&eacute; des Informations dInstallation. Mais cette obligation ne sapplique pas si ni vous ni aucune tierce partie ne d&eacute;tient la possibilit&eacute; dintaller un code objet modifi&eacute; sur le Produit Utilisateur (par exemple, le travail a &eacute;t&eacute; install&eacute; en m&eacute;moire morte).

  Lobligation de fournir les Informations dInstallation ninclue pas celle de continuer &agrave; fournir un service de support, une garantie ou des mises &agrave; jour pour un travail qui a &eacute;t&eacute; modifi&eacute; ou install&eacute; par le Destinataire, ou pour le Produit Utilisateur dans lequel il a &eacute;t&eacute; modifi&eacute; ou install&eacute;. Lacc&egrave;s &agrave; un r&eacute;seau peut &ecirc;tre rejet&eacute; quand la modification elle-m&ecirc;me affecte mat&eacute;riellement et d&eacute;favorablement les op&eacute;rations du r&eacute;seau ou viole les r&egrave;gles et protocoles de communication au travers du r&eacute;seau.

  Le Source Correspondant achemin&eacute; et les Informations dInstallation fournies, en accord avec cet article, doivent &ecirc;tre dans un format publiquement document&eacute; (et dont une impl&eacute;mentation est disponible aupr&egrave;s du public sous forme de code source) et ne doit n&eacute;cessiter aucune cl&eacute; ou mot de passe sp&eacute;cial pour le d&eacute;paquetage, la lecture ou la copie.

  Article 7. Termes additionnels.

  Les &laquo;permissions additionelles&raquo; d&eacute;signent les termes qui suppl&eacute;mentent ceux de cette Licence en &eacute;mettant des exceptions &agrave; lune ou plusieurs de ses conditions. Les permissions additionnelles qui sont applicables au Programme entier doivent &ecirc;tre trait&eacute;es comme si elles &eacute;taient incluent dans cette Licence, dans les limites de leur validit&eacute; suivant la loi applicable. Si des permissions additionnelles sappliquent seulement &agrave; une partie du Programme, cette partie peut &ecirc;tre utilis&eacute;e s&eacute;par&eacute;ment suivant ces permissions, mais le Programme tout entier reste gouvern&eacute; par cette Licence sans regard aux permissions additionelles.

  Quand vous acheminez une copie dun Travail Couvert, vous pouvez &agrave; votre convenance &ocirc;ter toute permission additionelle de cette copie, ou de nimporte quelle partie de celui-ci. (Des permissions additionnelles peuvent &ecirc;tre r&eacute;dig&eacute;es de fa&ccedil;on &agrave; requ&eacute;rir leur propre suppression dans certains cas o&ugrave; vous modifiez le travail.) Vous pouvez placer les permissions additionnelles sur le mat&eacute;riel achemin&eacute;, ajout&eacute;es par vous &agrave; un Travail Couvert pour lequel vous avez ou pouvez donner les permissions de Droit dAuteur (copyright) appropri&eacute;es.

  Nonobstant toute autre clause de cette Licence, pour tout constituant que vous ajoutez &agrave; un Travail Couvert, vous pouvez (si autoris&eacute; par les titulaires de Droit dAuteur pour ce constituant) suppl&eacute;menter les termes de cette Licence avec des termes :

    * a) qui rejettent la garantie ou limitent la responsabilit&eacute; de fa&ccedil;on diff&eacute;rente des termes des articles 15 et 16 de cette Licence ; ou
    * b) qui requi&egrave;rent la pr&eacute;servation de notices l&eacute;gales raisonnables sp&eacute;cifi&eacute;es ou les attributions dauteur dans ce constituant ou dans les Notices L&eacute;gales Appropri&eacute;es affich&eacute;es par les travaux qui le contiennent ; ou
    * c) qui prohibent la repr&eacute;sentation incorrecte de lorigine de ce constituant, ou qui requi&egrave;rent que les versions modifi&eacute;es dun tel constituant soit marqu&eacute;es par des moyens raisonnables comme diff&eacute;rentes de la version originale ; ou
    * d) qui limitent lusage &agrave; but publicitaire des noms des conc&eacute;dants de licence et des auteurs du constituant ; ou
    * e) qui refusent &agrave; accorder des droits selon la l&eacute;gislation relative aux marques commerciales, pour lutilisation dans des noms commerciaux, marques commerciales ou marques de services ; ou
    * f) qui requi&egrave;rent lindemnisation des conc&eacute;dants de licences et auteurs du constituant par quiconque achemine ce constituant (ou des versions modifi&eacute;es de celui-ci) en assumant contractuellement la responsabilit&eacute; envers le Destinataire, pour toute responsabilit&eacute; que ces engagements contractuels imposent directement &agrave; ces octroyants de licences et auteurs.

  Tous les autres termes additionnels non permissifs sont consid&eacute;r&eacute;s comme des &laquo;restrictions avanc&eacute;es&raquo; dans le sens de larticle 10. Si le Programme tel que vous lavez re&ccedil;u, ou toute partie de celui-ci, contient une notice &eacute;tablissant quil est gouvern&eacute; par cette Licence en m&ecirc;me temps quun terme qui est une restriction avanc&eacute;e, vous pouvez &ocirc;ter ce terme. Si un document de licence contient une restriction avanc&eacute;e mais permet la reconcession de licence ou lacheminement suivant cette Licence, vous pouvez ajouter un Travail Couvert constituant gouvern&eacute; par les termes de ce document de licence, pourvu que la restriction avanc&eacute;e ne survit pas &agrave; un telle cession de licence ou acheminement.

  Si vous ajoutez des termes &agrave; un Travail Couvert en accord avec cet article, vous devez placer, dans les fichiers sources appropri&eacute;s, une d&eacute;claration des termes additionnels qui sappliquent &agrave; ces fichiers, ou une notice indiquant o&ugrave; trouver les termes applicables.

  Les termes additionnels, quils soient permissifs ou non permissifs, peuvent &ecirc;tre &eacute;tablis sous la forme dune licence &eacute;crite s&eacute;par&eacute;ment, ou &eacute;tablis comme des exceptions ; les obligations ci-dessus sappliquent dans chacun de ces cas.

Article 8. Terminaison.

  Vous ne pouvez ni propager ni modifier un Travail Couvert autrement que suivant les termes de cette Licence. Toute autre tentative de le propager ou le modifier est nulle et terminera automatiquement vos droits selon cette Licence (y compris toute licence de brevet accord&eacute;e selon le troisi&egrave;me paragraphe de larticle 11).

  Cependant, si vous cessez toute violation de cette Licence, alors votre licence depuis un titulaire de Droit dAuteur (copyright) est r&eacute;instaur&eacute;e (a) &agrave; titre provisoire &agrave; moins que et jusqu&agrave; ce que le titulaire de Droit dAuteur termine finalement et explicitement votre licence, et (b) de fa&ccedil;on permanente si le titulaire de Droit dAuteur ne parvient pas &agrave; vous notifier de la violation par quelque moyen raisonnable dans les soixante (60) jours apr&egrave;s la cessation.

  De plus, votre licence depuis un titulaire particulier de Droit dAuteur est r&eacute;instaur&eacute;e de fa&ccedil;on permanente si ce titulaire vous notifie de la violation par quelque moyen raisonnable, cest la premi&egrave;re fois que vous avez re&ccedil;u une notification deviolation de cette Licence (pour un travail quelconque) depuis ce titulaire de Droit dAuteur, et vous r&eacute;solvez la violation dans les trente (30) jours qui suivent votre r&eacute;ception de la notification.

  La terminaison de vos droits suivant cette section ne terminera pas les licences des parties qui ont re&ccedil;u des copies ou droits de votre part suivant cette Licence. Si vos droits ont &eacute;t&eacute; termin&eacute;s et non r&eacute;instaur&eacute;s de fa&ccedil;on permanente, vous n&ecirc;tes plus qualifi&eacute; &agrave; recevoir de nouvelles licences pour les m&ecirc;mes constituants selon larticle 10.
Article 9. Acceptation non requise pour obtenir des copies.

  Vous n&ecirc;tes pas oblig&eacute; daccepter cette licence afin de recevoir ou ex&eacute;cuter une copie du Programme. La propagation asservie dun Travail Couvert qui se produit simplement en cons&eacute;quence dune transmission d&eacute;gal-&agrave;-&eacute;gal pour recevoir une copie ne n&eacute;cessite pas lacceptation. Cependant, rien dautre que cette Licence ne vous accorde la permission de propager ou modifier un quelconque Travail Couvert. Ces actions enfreignent le Droit dAuteur si vous nacceptez pas cette Licence. Par cons&eacute;quent, en modifiant ou propageant un Travail Couvert, vous indiquez votre acceptation de cette Licence pour agir ainsi.

  Article 10. Cession automatique de Licence aux Destinataires et interm&eacute;diaires.

  Chaque fois que vous acheminez un Travail Couvert, le Destinataire re&ccedil;oit automatiquement une licence depuis les conc&eacute;dants originaux, pour ex&eacute;cuter, modifier et propager ce travail, suivant les termes de cette Licence. Vous n&ecirc;tes pas responsable du renforcement de la conformation des tierces parties avec cette Licence.

  Une &laquo;transaction dentit&eacute;&raquo; d&eacute;signe une transaction qui transf&egrave;re le contr&ocirc;le dune organisation, ou de substantiellement tous ses actifs, ou la subdivision dune organisation, ou la fusion de plusieurs organisations. Si la propagation dun Travail Couvert r&eacute;sulte dune transaction dentit&eacute;, chaque partie &agrave; cette transaction qui re&ccedil;oit une copie du travail re&ccedil;oit aussi les licences pour le travail que le pr&eacute;d&eacute;cesseur int&eacute;ress&eacute; &agrave; cette partie avait ou pourrait donner selon le paragraphe pr&eacute;c&eacute;dent, plus un droit de possession du Source Correspondant de ce travail depuis le pr&eacute;d&eacute;cesseur int&eacute;ress&eacute; si ce pr&eacute;d&eacute;cesseur en dispose ou peut lobtenir par des efforts raisonnables.

  Vous ne pouvez imposer aucune restriction avanc&eacute;e dans lexercice des droits accord&eacute;s ou affirm&eacute;s selon cette Licence. Par exemple, vous ne pouvez imposer aucun paiement pour la licence, aucune royaltie, ni aucune autre charge pour lexercice des droits accord&eacute;s selon cette Licence ; et vous ne pouvez amorcer aucun litige judiciaire (y compris une r&eacute;clamation crois&eacute;e ou contre-r&eacute;clamation dans un proc&egrave;s) sur lall&eacute;gation quune revendication de brevet est enfreinte par la r&eacute;alisation, lutilisation, la vente, loffre de vente, ou limportation du Programme ou dune quelconque portion de celui-ci.

Article 11. Brevets.

  Un &laquo;contributeur&raquo; est un titulaire de Droit dAuteur (copyright) qui autorise lutilisation selon cette Licence du Programme ou du travail sur lequel le Programme est bas&eacute;. Le travail ainsi soumis &agrave; licence est appel&eacute; la &laquo;version contributive&raquo; de ce contributeur.

  Les &laquo;revendications de brevet essentielles&raquo; sont toutes les revendications de brevets d&eacute;tenues ou contr&ocirc;l&eacute;es par le contributeur, quelles soient d&eacute;j&agrave; acquises par lui ou acquises subs&eacute;quemment, qui pourraient &ecirc;tre enfreintes de quelque mani&egrave;re, permises par cette Licence, sur la r&eacute;alisation, lutilisation ou la vente de la version contributive de celui-ci. Aux fins de cette d&eacute;finition, le &laquo;contr&ocirc;le&raquo; inclue le droit de conc&eacute;der des sous-licences de brevets dune mani&egrave;re consistante, n&eacute;cessaire et suffisante, avec les obligations de cette Licence.

  Chaque contributeur vous accorde une licence de brevet non exclusive, mondiale et libre de toute royaltie, selon les revendications de brevet essentielles, pour r&eacute;aliser, utiliser, vendre, offrir &agrave; la vente, importer et autrement ex&eacute;cuter, modifier et propager les contenus de sa version contributive.

  Dans les trois paragraphes suivants, une &laquo;licence de brevet&raquo; d&eacute;signe tous les accords ou engagements exprim&eacute;s, quel que soit le nom que vous lui donnez, de ne pas mettre en vigueur un brevet (telle quune permission explicite pour mettre en pratique un brevet, ou un accord pour ne pas poursuivre un Destinataire pour cause de violation de brevet). &laquo;Accorder&raquo; une telle licence de brevet &agrave; une partie signifie conclure un tel accord ou engagement &agrave; ne pas faire appliquer le brevet &agrave; cette partie.

  Si vous acheminez un Travail Couvert, d&eacute;pendant en connaissance dune licence de brevet, et si le Source Correspondant du travail nest pas disponible &agrave; quiconque copie, sans frais et suivant les termes de cette Licence, &agrave; travers un serveur r&eacute;seau publiquement acessible ou tout autre moyen imm&eacute;diatement accessible, alors vous devez soit (1) rendre la Source Correspondante ainsi disponible, soit (2) vous engager &agrave; vous priver pour vous-m&ecirc;me du b&eacute;n&eacute;fice de la licence de brevet pour ce travail particulier, soit (3) vous engager, dune fa&ccedil;on consistante avec les obligations de cette Licence, &agrave; &eacute;tendre la licence de brevet aux Destinataires de ce travail. &laquo;D&eacute;pendant en connaissance&raquo; signifie que vous avez effectivement connaissance que, selon la licence de brevet, votre acheminement du Travail Couvert dans un pays, ou lutilisation du Travail Couvert par votre Destinataire dans un pays, infreindrait un ou plusieurs brevets identifiables dans ce pays o&ugrave; vous avez des raisons de penser quils sont valides.

  Si, conform&eacute;ment &agrave; ou en liaison avec une m&ecirc;me transaction ou un m&ecirc;me arrangement, vous acheminez, ou propagez en procurant un acheminement de, un Travail Couvert et accordez une licence de brevet &agrave; lune des parties recevant le Travail Couvert pour lui permettre dutiliser, propager, modifier ou acheminer une copie sp&eacute;cifique du Travail Couvert, alors votre accord est automatiquement &eacute;tendu &agrave; tous les Destinataires du Travail Couvert et des travaux bas&eacute;s sur celui-ci.

  Une licence de brevet est &laquo;discriminatoire&raquo; si, dans le champ de sa couverture, elle ninclut pas un ou plusieurs des droits qui sont sp&eacute;cifiquement accord&eacute;s selon cette Licence, ou en prohibe lexercice, ou est conditionn&eacute;e par le non-exercice dun ou plusieurs de ces droits. Vous ne pouvez pas acheminer un Travail Couvert si vous &ecirc;tes partie &agrave; un arrangement selon lequel une partie tierce exer&ccedil;ant son activit&eacute; dans la distribution de logiciels et &agrave; laquelle vous effectuez un paiement fond&eacute; sur l&eacute;tendue de votre activit&eacute; dacheminement du travail, et selon lequel la partie tierce accorde, &agrave; une quelconque partie qui recevrait depuis vous le Travail Couvert, une licence de brevet discriminatoire (a) en relation avec les copies du Travail Couvert achemin&eacute;es par vous (ou les copies r&eacute;alis&eacute;es &agrave; partir de ces copies), ou (b) avant tout destin&eacute;e et en relation avec des produits sp&eacute;cifiques ou compilations contenant le Travail Couvert, &agrave; moins que vous ayez conclu cet arrangement ou que la licence de brevet ait &eacute;t&eacute; accord&eacute;e avant le 28 mars 2007.

  Rien dans cette Licence ne devrait &ecirc;tre interpr&eacute;t&eacute; comme devant exclure ou limiter toute licence implicite ou dautres moyens de d&eacute;fense &agrave; une infraction qui vous seraient autrement disponible selon la loi applicable relative aux brevets.
Article 12. Non abandon de la libert&eacute; des autres.

  Si des conditions vous sont impos&eacute;es (que ce soit par d&eacute;cision judiciaire, par un accord ou autrement) qui contredisent les conditions de cette Licence, elles ne vous excusent pas des conditions de cette Licence. Si vous ne pouvez pas acheminer un Travail Couvert de fa&ccedil;on &agrave; satisfaire simult&eacute;n&eacute;ment vos obligations suivant cette Licence et toutes autres obligations pertinentes, alors en cons&eacute;quence vous ne pouvez pas du tout lacheminer. Par exemple, si vous avez un accord sur des termes qui vous obligent &agrave; collecter pour le r&eacute;acheminement des royalties depuis ceux &agrave; qui vous acheminez le Programme, la seule fa&ccedil;on qui puisse vous permettre de satisfaire &agrave; la fois &agrave; ces termes et ceux de cette Licence sera de vous abstenir enti&egrave;rement dacheminer le Programme.

  Article 13. Utilisation avec la Licence G&eacute;n&eacute;rale Publique Affero GNU.

  Nonobstant toute autre clause de cette Licence, vous avez la permission de lier ou combiner tout Travail Couvert avec un travail plac&eacute; sous la version 3 de la Licence G&eacute;n&eacute;rale Publique GNU Affero (GNU Affero General Public License) en un seul travail combin&eacute;, et dacheminer le travail r&eacute;sultant. Les termes de cette Licence continueront &agrave; sappliquer &agrave; la partie formant un Travail Couvert, mais les obligations sp&eacute;ciales de la Licence G&eacute;n&eacute;rale Publique GNU Affero, article 13, concernant linteraction &agrave; travers un r&eacute;seau sappliqueront &agrave; la combinaison en tant que telle.

  Article 14. Versions r&eacute;vis&eacute;es de cette License.

  La Free Software Foundation peut publier des versions r&eacute;vis&eacute;es et/ou nouvelles de la Licence Publique G&eacute;n&eacute;rale GNU (GNU General Public License) de temps en temps. De telles version nouvelles resteront similaires dans lesprit avec la pr&eacute;sente version, mais peuvent diff&eacute;rer dans le d&eacute;tail afin de traiter de nouveaux probl&egrave;mes ou pr&eacute;occupations.

  Chaque version re&ccedil;oit un num&eacute;ro de version distinctif. Si le Programme indique quune version sp&eacute;cifique de la Licence Publique G&eacute;n&eacute;rale GNU &laquo;ou toute version ult&eacute;rieure&raquo; (or any later version) sapplique &agrave; celui-ci, vous avez le choix de suivre soit les termes et conditions de cette version num&eacute;rot&eacute;e, soit ceux de nimporte quelle version publi&eacute;e ult&eacute;rieurement par la Free Software Foundation. Si le Programme nindique pas une version sp&eacute;cifique de la Licence Publique G&eacute;n&eacute;rale GNU, vous pouvez choisir lune quelconque des versions qui ont &eacute;t&eacute; publi&eacute;es par la Free Software Foundation.

  Si le Programme sp&eacute;cifie quun interm&eacute;diaire peut d&eacute;cider quelles versions futures de la Licence G&eacute;n&eacute;rale Publique GNU peut &ecirc;tre utilis&eacute;e, la d&eacute;claration publique dacceptation dune version par cet interm&eacute;diaire vous autorise &agrave; choisir cette version pour le Programme.

  Des versions ult&eacute;rieures de la licence peuvent vous donner des permissions additionelles ou diff&eacute;rentes. Cependant aucune obligation additionelle nest impos&eacute;e &agrave; lun des auteurs ou titulaires de Droit dAuteur du fait de votre choix de suivre une version ult&eacute;rieure.

  Article 15. D&eacute;claration dabsence de garantie.

  IL NY A AUCUNE GARANTIE POUR LE PROGRAMME, DANS LES LIMITES PERMISES PAR LA LOI APPLICABLE. &Agrave; MOINS QUE CELA NE SOIT &Eacute;TABLI DIFF&Eacute;REMMENT PAR &Eacute;CRIT, LES PROPRI&Eacute;TAIRES DE DROITS ET/OU LES AUTRES PARTIES FOURNISSENT LE PROGRAMME &laquo;EN L&Eacute;TAT&raquo; SANS GARANTIE DAUCUNE SORTE, QUELLE SOIT EXPRIM&Eacute;E OU IMPLICITE, CECI COMPRENANT, SANS SE LIMITER &Agrave; CELLES-CI, LES GARANTIES IMPLICITES DE COMMERCIALISABILIT&Eacute; ET DAD&Eacute;QUATION &Agrave; UN OBJECTIF PARTICULIER. VOUS ASSUMEZ LE RISQUE ENTIER CONCERNANT LA QUALIT&Eacute; ET LES PERFORMANCES DU PROGRAMME. DANS L&Eacute;VENTUALIT&Eacute; O&Ugrave; LE PROGRAMME SAV&Eacute;RERAIT D&Eacute;FECTUEUX, VOUS ASSUMEZ LES CO&Ucirc;TS DE TOUS LES SERVICES, R&Eacute;PARATIONS OU CORRECTIONS N&Eacute;CESSAIRES.

  Article 16. Limitation de responsabilit&eacute;.

  EN AUCUNE AUTRE CIRCONSTANCE QUE CELLES REQUISES PAR LA LOI APPLICABLE OU ACCORD&Eacute;ES PAR &Eacute;CRIT, UN TITULAIRE DE DROITS SUR LE PROGRAMME, OU TOUT AUTRE PARTIE QUI MODIFIE OU ACHEMINE LE PROGRAMME COMME PERMIS CI-DESSUS, NE PEUT &Ecirc;TRE TENU POUR RESPONSABLE ENVERS VOUS POUR LES DOMMAGES, INCLUANT TOUT DOMMAGE G&Eacute;N&Eacute;RAL, SP&Eacute;CIAL, ACCIDENTEL OU INDUIT SURVENANT PAR SUITE DE LUTILISATION OU DE LINCAPACIT&Eacute; DUTILISER LE PROGRAMME (Y COMPRIS, SANS SE LIMITER &Agrave; CELLES-CI, LA PERTE DE DONN&Eacute;ES OU LINEXACTITUDE DES DONN&Eacute;ES RETOURN&Eacute;ES OU LES PERTES SUBIES PAR VOUS OU DES PARTIES TIERCES OU LINCAPACIT&Eacute; DU PROGRAMME &Agrave; FONCTIONNER AVEC TOUT AUTRE PROGRAMME), M&Ecirc;ME SI UN TEL TITULAIRE OU TOUTE AUTRE PARTIE A &Eacute;T&Eacute; AVIS&Eacute; DE LA POSSIBILIT&Eacute; DE TELS DOMMAGES.

  Article 17. Interpr&eacute;tation des sections 15 et 16.

  Si la d&eacute;claration dabsence de garantie et la limitation de responsabilit&eacute; fournies ci-dessus ne peuvent prendre effet localement selon leurs termes, les cours de justice qui les examinent doivent appliquer la l&eacute;gislation locale qui approche au plus pr&egrave;s possible une lev&eacute;e absolue de toute responsabilit&eacute; civile li&eacute;e au Programme, &agrave; moins quune garantie ou assumation de responsabilit&eacute; accompagne une copie du Programme en &eacute;change dun paiement.

                     FIN DES TERMES ET CONDITIONS.
</pre>
EOF;

	echo $lang->sprintf($lang->license_step, $license);
	$output->print_footer('requirements_check');
}

function requirements_check()
{
	global $output, $mybb, $dboptions, $lang;

	$mybb->input['action'] = "requirements_check";
	$output->print_header($lang->req_check, 'requirements');
	echo $lang->req_step_top;
	$errors = array();
	$showerror = 0;
	
	if(!file_exists(MYBB_ROOT."/inc/config.php"))
	{
		if(!@rename(MYBB_ROOT."/inc/config.default.php", MYBB_ROOT."/inc/config.php"))
		{
			if(!$configwritable)
			{
				$errors[] = $lang->sprintf($lang->req_step_error_box, $lang->req_step_error_configdefaultfile);
				$configstatus = $lang->sprintf($lang->req_step_span_fail, $lang->not_writable);
				$showerror = 1;
			}
		}
	}

	// Check PHP Version
	$phpversion = @phpversion();
	if($phpversion < '4.1.0')
	{
		$errors[] = $lang->sprintf($lang->req_step_error_box, $lang->sprintf($lang->req_step_error_phpversion, $phpversion));
		$phpversion = $lang->sprintf($lang->req_step_span_fail, $phpversion);
		$showerror = 1;
	}
	else
	{
		$phpversion = $lang->sprintf($lang->req_step_span_pass, $phpversion);
	}
	
	if(function_exists('mb_detect_encoding'))
	{
		$mboptions[] = $lang->multi_byte;
	}
	
	if(function_exists('iconv'))
	{
		$mboptions[] = 'iconv';
	}
	
	// Check Multibyte extensions
	if(count($mboptions) < 1)
	{
		$mbstatus = $lang->sprintf($lang->req_step_span_fail, $lang->none);
	}
	else
	{
		$mbstatus = implode(', ', $mboptions);
	}

	// Check database engines
	if(count($dboptions) < 1)
	{
		$errors[] = $lang->sprintf($lang->req_step_error_box, $lang->req_step_error_dboptions);
		$dbsupportlist = $lang->sprintf($lang->req_step_span_fail, $lang->none);
		$showerror = 1;
	}
	else
	{
		foreach($dboptions as $dboption)
		{
			$dbsupportlist[] = $dboption['title'];
		}
		$dbsupportlist = implode(', ', $dbsupportlist);
	}

	// Check XML parser is installed
	if(!function_exists('xml_parser_create'))
	{
		$errors[] = $lang->sprintf($lang->req_step_error_box, $lang->req_step_error_xmlsupport);
		$xmlstatus = $lang->sprintf($lang->req_step_span_fail, $lang->not_installed);
		$showerror = 1;
	}
	else
	{
		$xmlstatus = $lang->sprintf($lang->req_step_span_pass, $lang->installed);
	}

	// Check config file is writable
	$configwritable = @fopen(MYBB_ROOT.'inc/config.php', 'w');
	if(!$configwritable)
	{
		$errors[] = $lang->sprintf($lang->req_step_error_box, $lang->req_step_error_configfile);
		$configstatus = $lang->sprintf($lang->req_step_span_fail, $lang->not_writable);
		$showerror = 1;
	}
	else
	{
		$configstatus = $lang->sprintf($lang->req_step_span_pass, $lang->writable);
	}
	@fclose($configwritable);

	// Check settings file is writable
	$settingswritable = @fopen(MYBB_ROOT.'inc/settings.php', 'w');
	if(!$settingswritable)
	{
		$errors[] = $lang->sprintf($lang->req_step_error_box, $lang->req_step_error_settingsfile);
		$settingsstatus = $lang->sprintf($lang->req_step_span_fail, $lang->not_writable);
		$showerror = 1;
	}
	else
	{
		$settingsstatus = $lang->sprintf($lang->req_step_span_pass, $lang->writable);
	}
	@fclose($settingswritable);

	// Check cache directory is writable
	$cachewritable = @fopen(MYBB_ROOT.'cache/test.write', 'w');
	if(!$cachewritable)
	{
		$errors[] = $lang->sprintf($lang->req_step_error_box, $lang->req_step_error_cachedir);
		$cachestatus = $lang->sprintf($lang->req_step_span_fail, $lang->not_writable);
		$showerror = 1;
		@fclose($cachewritable);
	}
	else
	{
		$cachestatus = $lang->sprintf($lang->req_step_span_pass, $lang->writable);
		@fclose($cachewritable);
	  	@my_chmod(MYBB_ROOT.'cache', '0777');
	  	@my_chmod(MYBB_ROOT.'cache/test.write', '0777');
		@unlink(MYBB_ROOT.'cache/test.write');
	}

	// Check upload directory is writable
	$uploadswritable = @fopen(MYBB_ROOT.'uploads/test.write', 'w');
	if(!$uploadswritable)
	{
		$errors[] = $lang->sprintf($lang->req_step_error_box, $lang->req_step_error_uploaddir);
		$uploadsstatus = $lang->sprintf($lang->req_step_span_fail, $lang->not_writable);
		$showerror = 1;
		@fclose($uploadswritable);
	}
	else
	{
		$uploadsstatus = $lang->sprintf($lang->req_step_span_pass, $lang->writable);
		@fclose($uploadswritable);
	  	@my_chmod(MYBB_ROOT.'uploads', '0777');
	  	@my_chmod(MYBB_ROOT.'uploads/test.write', '0777');
		@unlink(MYBB_ROOT.'uploads/test.write');
	}

	// Check avatar directory is writable
	$avatarswritable = @fopen(MYBB_ROOT.'uploads/avatars/test.write', 'w');
	if(!$avatarswritable)
	{
		$errors[] =  $lang->sprintf($lang->req_step_error_box, $lang->req_step_error_avatardir);
		$avatarsstatus = $lang->sprintf($lang->req_step_span_fail, $lang->not_writable);
		$showerror = 1;
		@fclose($avatarswritable);
	}
	else
	{
		$avatarsstatus = $lang->sprintf($lang->req_step_span_pass, $lang->writable);
		@fclose($avatarswritable);
		@my_chmod(MYBB_ROOT.'uploads/avatars', '0777');
	  	@my_chmod(MYBB_ROOT.'uploads/avatars/test.write', '0777');
		@unlink(MYBB_ROOT.'uploads/avatars/test.write');
  	}


	// Output requirements page
	echo $lang->sprintf($lang->req_step_reqtable, $phpversion, $dbsupportlist, $mbstatus, $xmlstatus, $configstatus, $settingsstatus, $cachestatus, $uploadsstatus, $avatarsstatus);

	if($showerror == 1)
	{
		$error_list = error_list($errors);
		echo $lang->sprintf($lang->req_step_error_tablelist, $error_list);
		echo "\n			<input type=\"hidden\" name=\"action\" value=\"{$mybb->input['action']}\" />";
		echo "\n				<div id=\"next_button\"><input type=\"submit\" class=\"submit_button\" value=\"{$lang->recheck}&raquo;\" /></div><br style=\"clear: both;\" />\n";
		$output->print_footer();
	}
	else
	{
		echo $lang->req_step_reqcomplete;
		$output->print_footer('database_info');
	}
}

function database_info()
{
	global $output, $dbinfo, $errors, $mybb, $dboptions, $lang;
	
	$mybb->input['action'] = 'database_info';
	$output->print_header($lang->db_config, 'dbconfig');

	echo "<script type=\"text/javascript\">
		function updateDBSettings()
		{
			dbengine = \$('dbengine').options[\$('dbengine').selectedIndex].value;
			$$('.db_settings').each(function(element)
			{
				element.className = 'db_settings';
				if(dbengine+'_settings' == element.id)
				{
					Element.show(element);
				}
				else
				{
					Element.hide(element);
				}
			});
		}
		Event.observe(window, 'load', updateDBSettings);
		</script>";

	// Check for errors from this stage
	if(is_array($errors))
	{
		$error_list = error_list($errors);
		echo $lang->sprintf($lang->db_step_error_config, $error_list);
	}
	else
	{
		echo $lang->db_step_config_db;
	}
	
	// Loop through database engines
	foreach($dboptions as $dbfile => $dbtype)
	{
		if($mybb->input['dbengine'] == $dbfile)
		{
			$dbengines .= "<option value=\"{$dbfile}\" selected=\"selected\">{$dbtype['title']}</option>";
		}
		else
		{
			$dbengines .= "<option value=\"{$dbfile}\">{$dbtype['title']}</option>";
		}
	}

	foreach($dboptions as $dbfile => $dbtype)
	{
		require_once MYBB_ROOT."inc/db_{$dbfile}.php";
		$db = new $dbtype['class'];
		$encodings = $db->fetch_db_charsets();
		$encoding_select = '';
		if(!$mybb->input['config'][$dbfile]['dbhost'])
		{
			$mybb->input['config'][$dbfile]['dbhost'] = "localhost";
		}
		if(!$mybb->input['config'][$dbfile]['tableprefix'])
		{
			$mybb->input['config'][$dbfile]['tableprefix'] = "mybb_";
		}
		if(!$mybb->input['config'][$dbfile]['encoding'])
		{
			$mybb->input['config'][$dbfile]['encoding'] = "utf8";
		}

		$class = '';
		if(!$first && !$mybb->input['dbengine'])
		{
			$mybb->input['dbengine'] = $dbfile;
			$first = true;
		}
		if($dbfile == $mybb->input['dbengine'])
		{
			$class = "_selected";
		}

		$db_info[$dbfile] = "
			<tbody id=\"{$dbfile}_settings\" class=\"db_settings db_type{$class}\">
				<tr>
					<th colspan=\"2\" class=\"first last\">{$dbtype['title']} {$lang->database_settings}</th>
				</tr>";
			
		// SQLite gets some special settings
		if($dbfile == 'sqlite2' || $dbfile == 'sqlite3')
		{
			$db_info[$dbfile] .= "
				<tr class=\"alt_row\">
					<td class=\"first\"><label for=\"config_{$dbfile}_dbname\">{$lang->database_path}</label></td>
					<td class=\"last alt_col\"><input type=\"text\" class=\"text_input\" name=\"config[{$dbfile}][dbname]\" id=\"config_{$dbfile}_dbname\" value=\"".htmlspecialchars_uni($mybb->input['config'][$dbfile]['dbname'])."\" /></td>
				</tr>";
		}
		// Others get db host, username, password etc
		else
		{
			$db_info[$dbfile] .= "
				<tr class=\"alt_row\">
					<td class=\"first\"><label for=\"config_{$dbfile}_dbhost\">{$lang->database_host}</label></td>
					<td class=\"last alt_col\"><input type=\"text\" class=\"text_input\" name=\"config[{$dbfile}][dbhost]\" id=\"config_{$dbfile}_dbhost\" value=\"".htmlspecialchars_uni($mybb->input['config'][$dbfile]['dbhost'])."\" /></td>
				</tr>
				<tr>
					<td class=\"first\"><label for=\"config_{$dbfile}_dbuser\">{$lang->database_user}</label></td>
					<td class=\"last alt_col\"><input type=\"text\" class=\"text_input\" name=\"config[{$dbfile}][dbuser]\" id=\"config_{$dbfile}_dbuser\" value=\"".htmlspecialchars_uni($mybb->input['config'][$dbfile]['dbuser'])."\" /></td>
				</tr>
				<tr class=\"alt_row\">
					<td class=\"first\"><label for=\"config_{$dbfile}_dbpass\">{$lang->database_pass}</label></td>
					<td class=\"last alt_col\"><input type=\"password\" class=\"text_input\" name=\"config[{$dbfile}][dbpass]\" id=\"config_{$dbfile}_dbpass\" value=\"".htmlspecialchars_uni($mybb->input['config'][$dbfile]['dbpass'])."\" /></td>
				</tr>
				<tr class=\"last\">
					<td class=\"first\"><label for=\"config_{$dbfile}_dbname\">{$lang->database_name}</label></td>
					<td class=\"last alt_col\"><input type=\"text\" class=\"text_input\" name=\"config[{$dbfile}][dbname]\" id=\"config_{$dbfile}_dbname\" value=\"".htmlspecialchars_uni($mybb->input['config'][$dbfile]['dbname'])."\" /></td>
				</tr>";
		}

		// Now we're up to table settings
		$db_info[$dbfile] .= "
			<tr>
				<th colspan=\"2\" class=\"first last\">{$dbtype['title']} {$lang->table_settings}</th>
			</tr>
			<tr class=\"first\">
				<td class=\"first\"><label for=\"config_{$dbfile}_tableprefix\">{$lang->table_prefix}</label></td>
				<td class=\"last alt_col\"><input type=\"text\" class=\"text_input\" name=\"config[{$dbfile}][tableprefix]\" id=\"config_{$dbfile}_tableprefix\" value=\"".htmlspecialchars_uni($mybb->input['config'][$dbfile]['tableprefix'])."\" /></td>
			</tr>
			";
		
		// Encoding selection only if supported
		if(is_array($encodings))
		{
			$select_options = "";
			foreach($encodings as $encoding => $title)
			{
				if($mybb->input['config'][$dbfile]['encoding'] == $encoding)
				{
					$select_options .= "<option value=\"{$encoding}\" selected=\"selected\">{$title}</option>";
				}
				else
				{
					$select_options .= "<option value=\"{$encoding}\">{$title}</option>";
				}
			}
			$db_info[$dbfile] .= "
				<tr class=\"last\">
					<td class=\"first\"><label for=\"config_{$dbfile}_encoding\">{$lang->table_encoding}</label></td>
					<td class=\"last alt_col\"><select name=\"config[{$dbfile}][encoding]\" id=\"config_{$dbfile}_encoding\">{$select_options}</select></td>
				</tr>
				</tbody>";
		}
	}
	$dbconfig = implode("", $db_info);

	echo $lang->sprintf($lang->db_step_config_table, $dbengines, $dbconfig);
	$output->print_footer('create_tables');
}

function create_tables()
{
	global $output, $dbinfo, $errors, $mybb, $dboptions, $lang;
	
	if(!file_exists(MYBB_ROOT."inc/db_{$mybb->input['dbengine']}.php"))
	{
		$errors[] = $lang->db_step_error_invalidengine;
		database_info();
	}

	$config = $mybb->input['config'][$mybb->input['dbengine']];
	
	if(strstr($mybb->input['dbengine'], "sqlite") !== false)
	{
		if(strstr($config['dbname'], "./") !== false || strstr($config['dbname'], "../") !== false)
		{
			$errors[] = $lang->db_step_error_sqlite_invalid_dbname;
			database_info();
		}
	}

	// Attempt to connect to the db
	require_once MYBB_ROOT."inc/db_{$mybb->input['dbengine']}.php";
	switch($mybb->input['dbengine'])
	{
		case "sqlite3":
			$db = new DB_SQLite3;
			break;
		case "sqlite2":
			$db = new DB_SQLite2;
			break;
		case "pgsql":
			$db = new DB_PgSQL;
			break;
		case "mysqli":
			$db = new DB_MySQLi;
			break;
		default:
			$db = new DB_MySQL;
	}
 	$db->error_reporting = 0;

	$connect_array = array(
		"hostname" => $config['dbhost'],
		"username" => $config['dbuser'],
		"password" => $config['dbpass'],
		"database" => $config['dbname'],
		"encoding" => $config['encoding']
	);

	$connection = $db->connect($connect_array);
	if(!$connection)
	{
		$errors[] = $lang->sprintf($lang->db_step_error_noconnect, $config['dbhost']);
	}
	// double check if the DB exists for MySQL
	elseif(method_exists($db, 'select_db') && !$db->select_db($config['dbname']))
	{
		$errors[] = $lang->sprintf($lang->db_step_error_nodbname, $config['dbname']);
	}

	if(is_array($errors))
	{
		database_info();
	}
	
	// Decide if we can use a database encoding or not
	if($db->fetch_db_charsets() != false)
	{
		$db_encoding = "\$config['database']['encoding'] = '{$config['encoding']}';";
	}
	else
	{
		$db_encoding = "// \$config['database']['encoding'] = '{$config['encoding']}';";
	}
	
	// Write the configuration file
	$configdata = "<?php
/**
 * Configuration de la base de donnes
 *
 * Merci de consulter le Wiki MyBB pour une configuration
 * avance de la base de donnes pour les grosses installations
 * http://wiki.mybboard.net/
 */

\$config['database']['type'] = '{$mybb->input['dbengine']}';
\$config['database']['database'] = '{$config['dbname']}';
\$config['database']['table_prefix'] = '{$config['tableprefix']}';

\$config['database']['hostname'] = '{$config['dbhost']}';
\$config['database']['username'] = '{$config['dbuser']}';
\$config['database']['password'] = '{$config['dbpass']}';

/**
 * Rpertoire de l'Administration
 *  Pour des raisons de scurit, il vous est recommand
 *  de renommer votre dossier d'administration.
 *  Vous devez alors ajuster la valeur ci-dessous 
 *  pour pointer sur le nouveau rpertoire.
 */

\$config['admin_dir'] = 'admin';

/**
 * Cacher les liens vers l'administration
 *  Si vous voulez cacher tous les liens
 *  vers l'administration sur le haut du forum
 *  aprs avoir renomm le rpertoire d'administration,
 *  mettez ceci &aacute; 1.
 */

\$config['hide_admin_links'] = 0;

/**
 * Configuration du cache-donnes
 *  Le cache des donnes est un cache temporaire
 *  des donnes le plus frquemment accdes dans MyBB.
 *  Par dfaut, la base de donnes est utilise pour
 *  stocker ces donnes.
 *
 *  Si vous voulez utiliser le systme de fichiers (rpertoire cache/), MemCache ou eAccelerator
 *  vous pouvez changer la valeur ci-dessous de 'files', 'memcache' ou 'eaccelerator' &aacute; 'db'.
 */

\$config['cache_store'] = 'db';

/**
 * Configuration Memcache
 *  Si vous utilisez memcache dans votre cache-donnes,
 *  vous devez configurer l'hte et le port
 *  de votre serveur memcache ci-dessous.
 *
 * Si vous n'utilisez pas memcache, ignorez cette section.
 */

\$config['memcache_host'] = 'localhost';
\$config['memcache_port'] = 11211;

/**
 * Super Administrateurs
 *  Une liste spare par des virgules des IDs d'utilisateurs
 *  qui ne peuvent tre dits, supprims ou bannis dans
 *  l'administration.
 *  Les permissions d'administrateurs pour ces utilisateurs
 *  ne peuvent plus tre altres.
 */

\$config['super_admins'] = '1';

/**
 * Encodage de la base de donnes
 *  Si vous voulez prciser l'encodage de MyBB dcommentez
 *  la ligne ci-dessous (si ce n'est pas dj&aacute; fait) et changez
 *  la valeur actuelle par l'encodage MySQL :
 *  http://dev.mysql.com/doc/refman/5.1/en/charset-mysql.html
 */

{$db_encoding}

/**
 * Supprimer automatiquement les suivis
 *  Le systme de tches MyBB peut supprimer
 *  diffrents suivis crs par MyBB. 
 *  Pour activer cette fonctionnalit, donnez ci-dessous
 *  le nombre de jours aprs lesquels les suivis vont tre supprims.
 *  Si vous mettez la valeur &aacute; 0, les suivis ne seront pas supprims.
 */

\$config['log_pruning'] = array(
	'admin_logs' => 365, // Suivis d'administrateur
	'mod_logs' => 365, // Suivis de modrateur
	'task_logs' => 30, // Suivis de tches
	'mail_logs' => 180, // Suivis de courriers collectifs
	'user_mail_logs' => 180, // Suivis des emails des utilisateurs
	'promotion_logs' => 180 // Suivis de promotions de groupes
);
 
?>";

	$file = fopen(MYBB_ROOT.'inc/config.php', 'w');
	fwrite($file, $configdata);
	fclose($file);

	// Error reporting back on
 	$db->error_reporting = 1;

	$output->print_header($lang->table_creation, 'createtables');
	echo $lang->sprintf($lang->tablecreate_step_connected, $dboptions[$mybb->input['dbengine']]['short_title'], $db->get_version());
	
	if($dboptions[$mybb->input['dbengine']]['structure_file'])
	{
		$structure_file = $dboptions[$mybb->input['dbengine']]['structure_file'];
	}
	else
	{
		$structure_file = 'mysql_db_tables.php';
	}

	require_once INSTALL_ROOT."resources/{$structure_file}";
	foreach($tables as $val)
	{
		$val = preg_replace('#mybb_(\S+?)([\s\.,\(]|$)#', $config['tableprefix'].'\\1\\2', $val);
		$val = preg_replace('#;$#', $db->build_create_table_collation().";", $val);
		preg_match('#CREATE TABLE (\S+)(\s?|\(?)\(#i', $val, $match);
		if($match[1])
		{
			$db->drop_table($match[1], false, false);
			echo $lang->sprintf($lang->tablecreate_step_created, $match[1]);
		}
		$db->query($val);
		if($match[1])
		{
			echo $lang->done . "<br />\n";
		}
	}
	echo $lang->tablecreate_step_done;
	$output->print_footer('populate_tables');
}

function populate_tables()
{
	global $output, $lang;

	require MYBB_ROOT.'inc/config.php';
	$db = db_connection($config);

	$output->print_header($lang->table_population, 'tablepopulate');
	echo $lang->sprintf($lang->populate_step_insert);

	if($dboptions[$db->type]['population_file'])
	{
		$population_file = $dboptions[$db->type]['population_file'];
	}
	else
	{
		$population_file = 'mysql_db_inserts.php';
	}

	require_once INSTALL_ROOT."resources/{$population_file}";
	foreach($inserts as $val)
	{
		$val = preg_replace('#mybb_(\S+?)([\s\.,]|$)#', $config['database']['table_prefix'].'\\1\\2', $val);
		$db->query($val);
	}
	// Update the fid sequence for PgSQL
	if($config['database']['type'] == "pgsql")
	{
		$db->query("ALTER SEQUENCE ".$config['database']['table_prefix']."forums_fid_seq RESTART WITH 3");
	}

	echo $lang->populate_step_inserted;
	$output->print_footer('templates');
}

function insert_templates()
{
	global $output, $cache, $db, $lang;

	require MYBB_ROOT.'inc/config.php';
	$db = db_connection($config);

	require_once MYBB_ROOT.'inc/class_datacache.php';
	$cache = new datacache;

	$output->print_header($lang->theme_installation, 'theme');

	echo $lang->theme_step_importing;

	$db->delete_query("themes");
	$db->delete_query("templates");
	$db->delete_query("themestylesheets");
	my_rmdir_recursive(MYBB_ROOT."cache/themes", array(MYBB_ROOT."cache/themes/index.html"));

	$insert_array = array(
		'title' => 'Templates par d&eacute;faut'
	);
	$templateset = $db->insert_query("templatesets", $insert_array);

	$contents = @file_get_contents(INSTALL_ROOT.'resources/mybb_theme.xml');
	if(file_exists(MYBB_ROOT.$mybb->config['admin_dir']."/inc/functions_themes.php"))
	{ 
		require_once MYBB_ROOT.$mybb->config['admin_dir']."/inc/functions_themes.php";
	}
	elseif(file_exists(MYBB_ROOT."admin/inc/functions_themes.php"))
	{
		require_once MYBB_ROOT."admin/inc/functions_themes.php";
		
	}
	else
	{
		$output->print_error("Assurez-vous que votre dossier admin est correctement upload&eacute;.");
	}
	$theme_id = import_theme_xml($contents, array("templateset" => -2, "version_compat" => 1));
	$tid = build_new_theme("Default", null, $theme_id);
	
	// Update our properties template set to the correct one
	$query = $db->simple_select("themes", "properties", "tid='{$tid}'", array('limit' => 1));
	$properties = unserialize($db->fetch_field($query, "properties"));
	$properties['templateset'] = $templateset;
	unset($properties['inherited']['templateset']);

	$db->update_query("themes", array("def" => 1, "properties" => $db->escape_string(serialize($properties))), "tid='{$tid}'");

	echo $lang->theme_step_imported;
	$output->print_footer('configuration');
}

function configure()
{
	global $output, $mybb, $errors, $lang;
	
	$output->print_header($lang->board_config, 'config');

	// If board configuration errors
	if(is_array($errors))
	{
		$error_list = error_list($errors);
		echo $lang->sprintf($lang->config_step_error_config, $error_list);

		$bbname = htmlspecialchars($mybb->input['bbname']);
		$bburl = htmlspecialchars($mybb->input['bburl']);
		$websitename = htmlspecialchars($mybb->input['websitename']);
		$websiteurl = htmlspecialchars($mybb->input['websiteurl']);
		$cookiedomain = htmlspecialchars($mybb->input['cookiedomain']);
		$cookiepath = htmlspecialchars($mybb->input['cookiepath']);
		$contactemail =  htmlspecialchars($mybb->input['contactemail']);
	}
	else
	{
		$bbname = 'Forums';
		$cookiedomain = '';
		$cookiepath = '/';
		$websiteurl = $hostname.'/';
		$websitename = 'Votre site web';
		$contactemail = '';
		// Attempt auto-detection
		if($_SERVER['HTTP_HOST'])
		{
			$hostname = 'http://'.$_SERVER['HTTP_HOST'];
			$cookiedomain = '.'.$_SERVER['HTTP_HOST'];
		}
		elseif($_SERVER['SERVER_NAME'])
		{
			$hostname = 'http://'.$_SERVER['SERVER_NAME'];
			$cookiedomain = '.'.$_SERVER['SERVER_NAME'];
		}
		
		if($_SERVER['HTTP_HOST'] == 'localhost' || $_SERVER['SERVER_NAME'] == 'localhost')
		{
			$cookiedomain = '';
		}
		
		if($_SERVER['SERVER_PORT'] && $_SERVER['SERVER_PORT'] != 80 && !preg_match("#:[0-9]#i", $hostname))
		{
			$hostname .= ':'.$_SERVER['SERVER_PORT'];
		}
		
		$currentlocation = get_current_location();
		if($currentlocation)
		{
			// TODO: Change this to find the last position of /install/
			$pos = my_strpos($currentlocation, '/install/');
			if($pos === 0)
			{
				$cookiepath = "/";
			}
			else
			{
				$cookiepath = my_substr($currentlocation, 0, $pos).'/';
			}
		}
		
		$currentscript = $hostname.get_current_location();
		
		if($currentscript)
		{
			$bburl = my_substr($currentscript, 0, my_strpos($currentscript, '/install/'));
		}
		
		if($_SERVER['SERVER_ADMIN'])
		{
			$contactemail = $_SERVER['SERVER_ADMIN'];
		}
	}

	echo $lang->sprintf($lang->config_step_table, $bbname, $bburl, $websitename, $websiteurl, $cookiedomain, $cookiepath, $contactemail);
	$output->print_footer('adminuser');
}

function create_admin_user()
{
	global $output, $mybb, $errors, $db, $lang;
	
	$mybb->input['action'] = "adminuser";
	// If no errors then check for errors from last step
	if(!is_array($errors))
	{
		if(empty($mybb->input['bburl']))
		{
			$errors[] = $lang->config_step_error_url;
		}
		if(empty($mybb->input['bbname']))
		{
			$errors[] = $lang->config_step_error_name;
		}
		if(is_array($errors))
		{
			configure();
		}
	}
	$output->print_header($lang->create_admin, 'admin');

	if(is_array($errors))
	{
		$error_list = error_list($errors);
		echo $lang->sprintf($lang->admin_step_error_config, $error_list);
		$adminuser = $mybb->input['adminuser'];
		$adminemail = $mybb->input['adminemail'];
	}
	else
	{
		require MYBB_ROOT.'inc/config.php';
		$db = db_connection($config);

		echo $lang->admin_step_setupsettings;

		$settings = file_get_contents(INSTALL_ROOT.'resources/settings.xml');
		$parser = new XMLParser($settings);
		$parser->collapse_dups = 0;
		$tree = $parser->get_tree();

		// Insert all the settings
		foreach($tree['settings'][0]['settinggroup'] as $settinggroup)
		{
			$groupdata = array(
				'name' => $db->escape_string($settinggroup['attributes']['name']),
				'title' => $db->escape_string($settinggroup['attributes']['title']),
				'description' => $db->escape_string($settinggroup['attributes']['description']),
				'disporder' => intval($settinggroup['attributes']['disporder']),
				'isdefault' => $settinggroup['attributes']['isdefault'],
			);
			$gid = $db->insert_query('settinggroups', $groupdata);
			++$groupcount;
			foreach($settinggroup['setting'] as $setting)
			{
				$settingdata = array(
					'name' => $db->escape_string($setting['attributes']['name']),
					'title' => $db->escape_string($setting['title'][0]['value']),
					'description' => $db->escape_string($setting['description'][0]['value']),
					'optionscode' => $db->escape_string($setting['optionscode'][0]['value']),
					'value' => $db->escape_string($setting['settingvalue'][0]['value']),
					'disporder' => intval($setting['disporder'][0]['value']),
					'gid' => $gid
				);

				$db->insert_query('settings', $settingdata);
				$settingcount++;
			}
		}

		if(my_substr($mybb->input['bburl'], -1, 1) == '/')
		{
			$mybb->input['bburl'] = my_substr($mybb->input['bburl'], 0, -1);
		}

		$db->update_query("settings", array('value' => $db->escape_string($mybb->input['bbname'])), "name='bbname'");
		$db->update_query("settings", array('value' => $db->escape_string($mybb->input['bburl'])), "name='bburl'");
		$db->update_query("settings", array('value' => $db->escape_string($mybb->input['websitename'])), "name='homename'");
		$db->update_query("settings", array('value' => $db->escape_string($mybb->input['websiteurl'])), "name='homeurl'");
		$db->update_query("settings", array('value' => $db->escape_string($mybb->input['cookiedomain'])), "name='cookiedomain'");
		$db->update_query("settings", array('value' => $db->escape_string($mybb->input['cookiepath'])), "name='cookiepath'");
		$db->update_query("settings", array('value' => $db->escape_string($mybb->input['contactemail'])), "name='adminemail'");
		$db->update_query("settings", array('value' => 'mailto:'.$db->escape_string($mybb->input['contactemail'])), "name='contactlink'");

		write_settings();

		echo $lang->sprintf($lang->admin_step_insertesettings, $settingcount, $groupcount);

		include_once MYBB_ROOT."inc/functions_task.php";
		$tasks = file_get_contents(INSTALL_ROOT.'resources/tasks.xml');
		$parser = new XMLParser($tasks);
		$parser->collapse_dups = 0;
		$tree = $parser->get_tree();

		// Insert scheduled tasks
		foreach($tree['tasks'][0]['task'] as $task)
		{
			$new_task = array(
				'title' => $db->escape_string($task['title'][0]['value']),
				'description' => $db->escape_string($task['description'][0]['value']),
				'file' => $db->escape_string($task['file'][0]['value']),
				'minute' => $db->escape_string($task['minute'][0]['value']),
				'hour' => $db->escape_string($task['hour'][0]['value']),
				'day' => $db->escape_string($task['day'][0]['value']),
				'weekday' => $db->escape_string($task['weekday'][0]['value']),
				'month' => $db->escape_string($task['month'][0]['value']),
				'enabled' => $db->escape_string($task['enabled'][0]['value']),
				'logging' => $db->escape_string($task['logging'][0]['value'])
			);

			$new_task['nextrun'] = fetch_next_run($new_task);

			$db->insert_query("tasks", $new_task);
			$taskcount++;
		}

		echo $lang->sprintf($lang->admin_step_insertedtasks, $taskcount);

		$views = file_get_contents(INSTALL_ROOT.'resources/adminviews.xml');
		$parser = new XMLParser($views);
		$parser->collapse_dups = 0;
		$tree = $parser->get_tree();

		// Insert admin views
		foreach($tree['adminviews'][0]['view'] as $view)
		{
			$fields = array();
			foreach($view['fields'][0]['field'] as $field)
			{
				$fields[] = $field['attributes']['name'];
			}
			$conditions = array();
			
			if(is_array($view['conditions'][0]['condition']))
			{
				foreach($view['conditions'][0]['condition'] as $condition)
				{
					if(!$condition['value']) continue;
					if($condition['attributes']['is_serialized'] == 1)
					{
						$condition['value'] = unserialize($condition['value']);
					}
					$conditions[$condition['attributes']['name']] = $condition['value'];
				}
			}

			$new_view = array(
				"uid" => 0,
				"type" => $db->escape_string($view['attributes']['type']),
				"visibility" => intval($view['attributes']['visibility']),
				"title" => $db->escape_string($view['title'][0]['value']),
				"fields" => $db->escape_string(serialize($fields)),
				"conditions" => $db->escape_string(serialize($conditions)),
				"sortby" => $db->escape_string($view['sortby'][0]['value']),
				"sortorder" => $db->escape_string($view['sortorder'][0]['value']),
				"perpage" => intval($view['perpage'][0]['value']),
				"view_type" => $db->escape_string($view['view_type'][0]['value'])
			);
			$db->insert_query("adminviews", $new_view);
			$view_count++;
		}

		echo $lang->sprintf($lang->admin_step_insertedviews, $view_count);

		echo $lang->admin_step_createadmin;
	}

	echo $lang->sprintf($lang->admin_step_admintable, $adminuser, $adminemail);
	$output->print_footer('final');
}

function install_done()
{
	global $output, $db, $mybb, $errors, $cache, $lang;

	if(empty($mybb->input['adminuser']))
	{
		$errors[] = $lang->admin_step_error_nouser;
	}
	if(empty($mybb->input['adminpass']))
	{
		$errors[] = $lang->admin_step_error_nopassword;
	}
	if($mybb->input['adminpass'] != $mybb->input['adminpass2'])
	{
		$errors[] = $lang->admin_step_error_nomatch;
	}
	if(empty($mybb->input['adminemail']))
	{
		$errors[] = $lang->admin_step_error_noemail;
	}
	if(is_array($errors))
	{
		create_admin_user();
	}

	require MYBB_ROOT.'inc/config.php';
	$db = db_connection($config);
	
	require MYBB_ROOT.'inc/settings.php';
	$mybb->settings = &$settings;

	ob_start();
	$output->print_header($lang->finish_setup, 'finish');
	
	echo $lang->done_step_usergroupsinserted;
	
	// Insert all of our user groups from the XML file	
	$settings = file_get_contents(INSTALL_ROOT.'resources/usergroups.xml');
	$parser = new XMLParser($settings);
	$parser->collapse_dups = 0;
	$tree = $parser->get_tree();

	$admin_gid = '';
	$group_count = 0;
	foreach($tree['usergroups'][0]['usergroup'] as $usergroup)
	{
		// usergroup[cancp][0][value]
		$new_group = array();
		foreach($usergroup as $key => $value)
		{
			if($key == "gid" || !is_array($value))
			{
				continue;
			}
			
			$new_group[$key] = $db->escape_string($value[0]['value']);
		}
		$return_gid = $db->insert_query("usergroups", $new_group);		
		// If this group can access the admin CP and we haven't established the admin group - set it (just in case we ever change IDs)
		if($new_group['cancp'] == 1 && !$admin_gid)
		{
			$admin_gid = $return_gid;
		}
		$group_count++;
	}
	echo $lang->done . '</p>';
	
	echo $lang->done_step_admincreated;
	$now = TIME_NOW;
	$salt = random_str();
	$loginkey = generate_loginkey();
	$saltedpw = md5(md5($salt).md5($mybb->input['adminpass']));

	$newuser = array(
		'username' => $db->escape_string($mybb->input['adminuser']),
		'password' => $saltedpw,
		'salt' => $salt,
		'loginkey' => $loginkey,
		'email' => $db->escape_string($mybb->input['adminemail']),
		'usergroup' => $admin_gid, // assigned above
		'regdate' => $now,
		'lastactive' => $now,
		'lastvisit' => $now,
		'website' => '',
		'icq' => '',
		'aim' => '',
		'yahoo' => '',
		'msn' =>'',
		'birthday' => '',
		'signature' => '',
		'allownotices' => 1,
		'hideemail' => 0,
		'subscriptionmethod' => '0',
		'receivepms' => 1,
		'pmnotice' => 1,
		'pmnotify' => 1,
		'remember' => 1,
		'showsigs' => 1,
		'showavatars' => 1,
		'showquickreply' => 1,
		'invisible' => 0,
		'style' => '0',
		'timezone' => 0,
		'dst' => 0,
		'threadmode' => '',
		'daysprune' => 0,
		'regip' => $db->escape_string(get_ip()),
		'longregip' => intval(ip2long(get_ip())),
		'language' => '',
		'showcodebuttons' => 1,
		'tpp' => 0,
		'ppp' => 0,
		'referrer' => 0,
		'buddylist' => '',
		'ignorelist' => '',
		'pmfolders' => '',
		'notepad' => '',
		'showredirect' => 1
	);
	$db->insert_query('users', $newuser);
	echo $lang->done . '</p>';

	echo $lang->done_step_adminoptions;
	$adminoptions = file_get_contents(INSTALL_ROOT.'resources/adminoptions.xml');
	$parser = new XMLParser($adminoptions);
	$parser->collapse_dups = 0;
	$tree = $parser->get_tree();
	$insertmodule = array();
	
	$db->delete_query("adminoptions");
	
	// Insert all the admin permissions
	foreach($tree['adminoptions'][0]['user'] as $users)
	{			
		$uid = $users['attributes']['uid'];
		
		foreach($users['permissions'][0]['module'] as $module)
		{
			foreach($module['permission'] as $permission)
			{
				$insertmodule[$module['attributes']['name']][$permission['attributes']['name']] = $permission['value'];
			}
		}

		$defaultviews = array();
		foreach($users['defaultviews'][0]['view'] as $view)
		{
			$defaultviews[$view['attributes']['type']] = $view['value'];
		}
		
		$adminoptiondata = array(
			'uid' => intval($uid),
			'cpstyle' => '',
			'notes' => '',
			'permissions' => $db->escape_string(serialize($insertmodule)),
			'defaultviews' => $db->escape_string(serialize($defaultviews))
		);

		$insertmodule = array();

		$db->insert_query('adminoptions', $adminoptiondata);
	}
	echo $lang->done . '</p>';

	// Automatic Login
	my_unsetcookie("sid");
	my_unsetcookie("mybbuser");
	my_setcookie('mybbuser', $uid.'_'.$loginkey, null, true);
	ob_end_flush();

	// Make fulltext columns if supported
	if($db->supports_fulltext('threads'))
	{
		$db->create_fulltext_index('threads', 'subject');
	}
	if($db->supports_fulltext_boolean('posts'))
	{
		$db->create_fulltext_index('posts', 'message');
	}

	// Register a shutdown function which actually tests if this functionality is working
	add_shutdown('test_shutdown_function');

	echo $lang->done_step_cachebuilding;
	require_once MYBB_ROOT.'inc/class_datacache.php';
	$cache = new datacache;
	$cache->update_version();
	$cache->update_attachtypes();
	$cache->update_smilies();
	$cache->update_badwords();
	$cache->update_usergroups();
	$cache->update_forumpermissions();
	$cache->update_stats();
	$cache->update_forums();
	$cache->update_moderators();
	$cache->update_usertitles();
	$cache->update_reportedposts();
	$cache->update_mycode();
	$cache->update_posticons();
	$cache->update_update_check();
	$cache->update_tasks();
	$cache->update_spiders();
	$cache->update_bannedips();
	$cache->update_banned();
	$cache->update_birthdays();
	$cache->update("plugins", array());
	$cache->update("internal_settings", array('encryption_key' => random_str(32)));
	echo $lang->done . '</p>';

	echo $lang->done_step_success;

	$written = 0;
	if(is_writable('./'))
	{
		$lock = @fopen('./lock', 'w');
		$written = @fwrite($lock, '1');
		@fclose($lock);
		if($written)
		{
			echo $lang->done_step_locked;
		}
	}
	if(!$written)
	{
		echo $lang->done_step_dirdelete;
	}
	echo $lang->done_subscribe_mailing;
	$output->print_footer('');
}

function db_connection($config)
{
	require_once MYBB_ROOT."inc/db_{$config['database']['type']}.php";
	switch($config['database']['type'])
	{
		case "sqlite3":
			$db = new DB_SQLite3;
			break;
		case "sqlite2":
			$db = new DB_SQLite2;
			break;
		case "pgsql":
			$db = new DB_PgSQL;
			break;
		case "mysqli":
			$db = new DB_MySQLi;
			break;
		default:
			$db = new DB_MySQL;
	}
	
	// Connect to Database
	define('TABLE_PREFIX', $config['database']['table_prefix']);

	$db->connect($config['database']);
	$db->set_table_prefix(TABLE_PREFIX);
	$db->type = $config['database']['type'];
	
	return $db;
}

function error_list($array)
{
	$string = "<ul>\n";
	foreach($array as $error)
	{
		$string .= "<li>{$error}</li>\n";
	}
	$string .= "</ul>\n";
	return $string;
}

function write_settings()
{
	global $db;
	
	$query = $db->simple_select('settings', '*', '', array('order_by' => 'title'));
	while($setting = $db->fetch_array($query))
	{
		$setting['value'] = str_replace("\"", "\\\"", $setting['value']);
		$settings .= "\$settings['{$setting['name']}'] = \"{$setting['value']}\";\n";
	}
	if(!empty($settings))
	{
		$settings = "<?php\n/*********************************\ \n  DO NOT EDIT THIS FILE, PLEASE USE\n  THE SETTINGS EDITOR\n\*********************************/\n\n{$settings}\n?>";
		$file = fopen(MYBB_ROOT."inc/settings.php", "w");
		fwrite($file, $settings);
		fclose($file);
	}
}

function test_shutdown_function()
{
	global $db;
	
	$db->update_query("settings", array('value' => 1), "name='useshutdownfunc'");
	write_settings();
}
?>